@@ -1,12 +1,13 @@
 package Silki::Schema::Policy;
 BEGIN {
-  $Silki::Schema::Policy::VERSION = '0.13';
+  $Silki::Schema::Policy::VERSION = '0.14';
 }
 
 use strict;
 use warnings;
 
 use DateTime::Format::Pg;
+use Encode qw( decode );
 use Lingua::EN::Inflect qw( PL_N );
 use Scalar::Util qw( blessed );
 
@@ -40,6 +41,16 @@ transform_all
         return $dt;
     };
 
+# This is a hack that should not be necessary, but DBD::Pg has a fixed list of
+# column types it will treat as utf-8, and user-defined types are not
+# included. See https://rt.cpan.org/Ticket/Display.html?id=40199 for details.
+my %text_types = map { $_ => 1 } qw( citext email_address filename );
+transform_all
+    matching { $text_types{ lc $_[0]->type() } } =>
+    inflate {
+        return decode( 'utf-8', $_[1] );
+    };
+
 has_one_namer {
     my $name = $_[0]->name();
     my @parts = map {lc} ( $name =~ /([A-Z][a-z]+)/g );
@@ -69,7 +80,7 @@ Silki::Schema::Policy - A Fey::Policy for Silki
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 AUTHOR
 
