@@ -1,7 +1,9 @@
 JSAN.use('DOM.Ready');
 JSAN.use('Silki.FileView');
 JSAN.use('Silki.PageTags');
+JSAN.use('Silki.ProcessStatus');
 JSAN.use('Silki.SystemLogs');
+JSAN.use('Silki.URI');
 JSAN.use('Silki.User');
 
 if ( typeof Silki == "undefined" ) {
@@ -11,6 +13,7 @@ if ( typeof Silki == "undefined" ) {
 Silki.instrumentAll = function () {
     new Silki.FileView ();
     new Silki.PageTags ();
+    new Silki.ProcessStatus ();
     new Silki.SystemLogs ();
 };
 
